==> applet-service-2.0.0-20200115.071606-4-sources.jar: com/bizvane/appletservice/models/vo/ShopStoreVo.java <==
package com.bizvane.appletservice.models.vo;

import java.util.List;

/**
 * 商品
 *
 * @author gs
 * @date 2019/3/18
 */
public class ShopStoreVo {
    private String ShopId;
    //商品名称
    private String goodsNo;
    //积分
    private String price;
    private String goodsName;
    //上架时间
    private String upperShelfTime;
    //商品图片
    private String coverImg;
    private List<String> bannerImgPaths;
    private String classifyId;
    //兑换数量
    private String actualSales;
    //限对数量
    private String restrictedNum;
    private String shelf;
    private String hot;
    private String distributionMode;
    private String goodsDetails;
    private List<ShopStoreSkuVo> shopStoreSkuVos;
    private List<ShopClassifyMapVo> classifyMapVos;
    private ShopVo shopVo;
    private String exchangeInstructions;

    public String getShopId() {
        return ShopId;
    }

    public void setShopId(String shopId) {
        ShopId = shopId;
    }

    public String getGoodsNo() {
        return goodsNo;
    }

    public void setGoodsNo(String goodsNo) {
        this.goodsNo = goodsNo;
    }

    public String getPrice() {
        return price;
    }

    public void setPrice(String price) {
        this.price = price;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }

    public String getUpperShelfTime() {
        return upperShelfTime;
    }

    public void setUpperShelfTime(String upperShelfTime) {
        this.upperShelfTime = upperShelfTime;
    }

    public String getCoverImg() {
        return coverImg;
    }

    public void setCoverImg(String coverImg) {
        this.coverImg = coverImg;
    }

    public List<String> getBannerImgPaths() {
        return bannerImgPaths;
    }

    public void setBannerImgPaths(List<String> bannerImgPaths) {
        this.bannerImgPaths = bannerImgPaths;
    }

    public String getClassifyId() {
        return classifyId;
    }

    public void setClassifyId(String classifyId) {
        this.classifyId = classifyId;
    }

    public String getActualSales() {
        return actualSales;
    }

    public void setActualSales(String actualSales) {
        this.actualSales = actualSales;
    }

    public String getRestrictedNum() {
        return restrictedNum;
    }

    public void setRestrictedNum(String restrictedNum) {
        this.restrictedNum = restrictedNum;
    }

    public String getShelf() {
        return shelf;
    }

    public void setShelf(String shelf) {
        this.shelf = shelf;
    }

    public String getHot() {
        return hot;
    }

    public void setHot(String hot) {
        this.hot = hot;
    }

    public String getDistributionMode() {
        return distributionMode;
    }

    public void setDistributionMode(String distributionMode) {
        this.distributionMode = distributionMode;
    }

    public String getGoodsDetails() {
        return goodsDetails;
    }

    public void setGoodsDetails(String goodsDetails) {
        this.goodsDetails = goodsDetails;
    }

    public List<ShopStoreSkuVo> getShopStoreSkuVos() {
        return shopStoreSkuVos;
    }

    public void setShopStoreSkuVos(List<ShopStoreSkuVo> shopStoreSkuVos) {
        this.shopStoreSkuVos = shopStoreSkuVos;
    }

    public List<ShopClassifyMapVo> getClassifyMapVos() {
        return classifyMapVos;
    }

    public void setClassifyMapVos(List<ShopClassifyMapVo> classifyMapVos) {
        this.classifyMapVos = classifyMapVos;
    }

    public ShopVo getShopVo() {
        return shopVo;
    }

    public void setShopVo(ShopVo shopVo) {
        this.shopVo = shopVo;
    }

    public String getExchangeInstructions() {
        return exchangeInstructions;
    }

    public void setExchangeInstructions(String exchangeInstructions) {
        this.exchangeInstructions = exchangeInstructions;
    }
}

==> applet-service-2.0.0-20200619.085014-9-sources.jar: com/bizvane/appletservice/models/vo/ShopStoreVo.java <==
package com.bizvane.appletservice.models.vo;

import java.util.List;

/**
 * 商品
 *
 * @author gs
 * @date 2019/3/18
 */
public class ShopStoreVo {
    private String ShopId;
    //商品名称
    private String goodsNo;
    //积分
    private String price;
    private String goodsName;
    //上架时间
    private String upperShelfTime;
    //商品图片
    private String coverImg;
    private List<String> bannerImgPaths;
    private String classifyId;
    //兑换数量
    private String actualSales;
    //限对数量
    private String restrictedNum;
    private String shelf;
    private String hot;
    private String distributionMode;
    private String goodsDetails;
    private List<ShopStoreSkuVo> shopStoreSkuVos;
    private List<ShopClassifyMapVo> classifyMapVos;
    private ShopVo shopVo;
    private String exchangeInstructions;
    private Integer exchangeStatus;
    private Integer exchangeCount;
    private Integer isWholeStore;

    public Integer getIsWholeStore() {
        return isWholeStore;
    }

    public void setIsWholeStore(Integer isWholeStore) {
        this.isWholeStore = isWholeStore;
    }

    public Integer getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(Integer exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }

    public Integer getExchangeCount() {
        return exchangeCount;
    }

    public void setExchangeCount(Integer exchangeCount) {
        this.exchangeCount = exchangeCount;
    }

    public String getShopId() {
        return ShopId;
    }

    public void setShopId(String shopId) {
        ShopId = shopId;
    }

    public String getGoodsNo() {
        return goodsNo;
    }

    public void setGoodsNo(String goodsNo) {
        this.goodsNo = goodsNo;
    }

    public String getPrice() {
        return price;
    }

    public void setPrice(String price) {
        this.price = price;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }

    public String getUpperShelfTime() {
        return upperShelfTime;
    }

    public void setUpperShelfTime(String upperShelfTime) {
        this.upperShelfTime = upperShelfTime;
    }

    public String getCoverImg() {
        return coverImg;
    }

    public void setCoverImg(String coverImg) {
        this.coverImg = coverImg;
    }

    public List<String> getBannerImgPaths() {
        return bannerImgPaths;
    }

    public void setBannerImgPaths(List<String> bannerImgPaths) {
        this.bannerImgPaths = bannerImgPaths;
    }

    public String getClassifyId() {
        return classifyId;
    }

    public void setClassifyId(String classifyId) {
        this.classifyId = classifyId;
    }

    public String getActualSales() {
        return actualSales;
    }

    public void setActualSales(String actualSales) {
        this.actualSales = actualSales;
    }

    public String getRestrictedNum() {
        return restrictedNum;
    }

    public void setRestrictedNum(String restrictedNum) {
        this.restrictedNum = restrictedNum;
    }

    public String getShelf() {
        return shelf;
    }

    public void setShelf(String shelf) {
        this.shelf = shelf;
    }

    public String getHot() {
        return hot;
    }

    public void setHot(String hot) {
        this.hot = hot;
    }

    public String getDistributionMode() {
        return distributionMode;
    }

    public void setDistributionMode(String distributionMode) {
        this.distributionMode = distributionMode;
    }

    public String getGoodsDetails() {
        return goodsDetails;
    }

    public void setGoodsDetails(String goodsDetails) {
        this.goodsDetails = goodsDetails;
    }

    public List<ShopStoreSkuVo> getShopStoreSkuVos() {
        return shopStoreSkuVos;
    }

    public void setShopStoreSkuVos(List<ShopStoreSkuVo> shopStoreSkuVos) {
        this.shopStoreSkuVos = shopStoreSkuVos;
    }

    public List<ShopClassifyMapVo> getClassifyMapVos() {
        return classifyMapVos;
    }

    public void setClassifyMapVos(List<ShopClassifyMapVo> classifyMapVos) {
        this.classifyMapVos = classifyMapVos;
    }

    public ShopVo getShopVo() {
        return shopVo;
    }

    public void setShopVo(ShopVo shopVo) {
        this.shopVo = shopVo;
    }

    public String getExchangeInstructions() {
        return exchangeInstructions;
    }

    public void setExchangeInstructions(String exchangeInstructions) {
        this.exchangeInstructions = exchangeInstructions;
    }
}
